@@ -1,10 +1,10 @@
 ;;; zenburn-theme.el --- A low contrast color theme for Emacs.
 
-;; Copyright (C) 2011-2017 Bozhidar Batsov
+;; Copyright (C) 2011-2018 Bozhidar Batsov
 
 ;; Author: Bozhidar Batsov <bozhidar@batsov.com>
 ;; URL: http://github.com/bbatsov/zenburn-emacs
-;; Version: 2.5
+;; Version: 2.6
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -33,6 +33,71 @@
 
 (deftheme zenburn "The Zenburn color theme")
 
+(defgroup zenburn-theme nil
+  "Zenburn theme."
+  :prefix "zenburn-theme-"
+  :link '(url-link :tag "GitHub" "http://github.com/bbatsov/zenburn-emacs")
+  :tag "Zenburn theme")
+
+;;;###autoload
+(defcustom zenburn-override-colors-alist '()
+  "Place to override default theme colors.
+
+You can override a subset of the theme's default colors by
+defining them in this alist."
+  :group 'zenburn-theme
+  :type '(alist
+          :key-type (string :tag "Name")
+          :value-type (string :tag " Hex")))
+
+(defcustom zenburn-use-variable-pitch nil
+  "Use variable pitch face for some headings and titles."
+  :type 'boolean
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
+(defcustom zenburn-height-minus-1 0.8
+  "Font size -1."
+  :type 'number
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
+(defcustom zenburn-height-plus-1 1.1
+  "Font size +1."
+  :type 'number
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
+(defcustom zenburn-height-plus-2 1.15
+  "Font size +2."
+  :type 'number
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
+(defcustom zenburn-height-plus-3 1.2
+  "Font size +3."
+  :type 'number
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
+(defcustom zenburn-height-plus-4 1.3
+  "Font size +4."
+  :type 'number
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
+(defcustom zenburn-scale-org-headlines nil
+  "Whether `org-mode' headlines should be scaled."
+  :type 'boolean
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
+(defcustom zenburn-scale-outline-headlines nil
+  "Whether `outline-mode' headlines should be scaled."
+  :type 'boolean
+  :group 'zenburn-theme
+  :package-version '(zenburn . "2.6"))
+
 ;;; Color Palette
 
 (defvar zenburn-default-colors-alist
@@ -47,23 +112,32 @@
     ("zenburn-bg+1"     . "#4F4F4F")
     ("zenburn-bg+2"     . "#5F5F5F")
     ("zenburn-bg+3"     . "#6F6F6F")
+    ("zenburn-red+2"    . "#ECB3B3")
     ("zenburn-red+1"    . "#DCA3A3")
     ("zenburn-red"      . "#CC9393")
     ("zenburn-red-1"    . "#BC8383")
     ("zenburn-red-2"    . "#AC7373")
     ("zenburn-red-3"    . "#9C6363")
     ("zenburn-red-4"    . "#8C5353")
+    ("zenburn-red-5"    . "#7C4343")
+    ("zenburn-red-6"    . "#6C3333")
     ("zenburn-orange"   . "#DFAF8F")
     ("zenburn-yellow"   . "#F0DFAF")
     ("zenburn-yellow-1" . "#E0CF9F")
     ("zenburn-yellow-2" . "#D0BF8F")
-    ("zenburn-green-1"  . "#5F7F5F")
+    ("zenburn-green-5"  . "#2F4F2F")
+    ("zenburn-green-4"  . "#3F5F3F")
+    ("zenburn-green-3"  . "#4F6F4F")
+    ("zenburn-green-2"  . "#5F7F5F")
+    ("zenburn-green-1"  . "#6F8F6F")
     ("zenburn-green"    . "#7F9F7F")
     ("zenburn-green+1"  . "#8FB28F")
     ("zenburn-green+2"  . "#9FC59F")
     ("zenburn-green+3"  . "#AFD8AF")
     ("zenburn-green+4"  . "#BFEBBF")
     ("zenburn-cyan"     . "#93E0E3")
+    ("zenburn-blue+3"   . "#BDE0F3")
+    ("zenburn-blue+2"   . "#ACE0E3")
     ("zenburn-blue+1"   . "#94BFF3")
     ("zenburn-blue"     . "#8CD0D3")
     ("zenburn-blue-1"   . "#7CB8BB")
@@ -78,16 +152,6 @@ Each element has the form (NAME . HEX).
 `+N' suffixes indicate a color is lighter.
 `-N' suffixes indicate a color is darker.")
 
-(defvar zenburn-override-colors-alist
-  '()
-  "Place to override default theme colors.
-
-You can override a subset of the theme's default colors by
-defining them in this alist before loading the theme.")
-
-(defvar zenburn-colors-alist
-  (append zenburn-default-colors-alist zenburn-override-colors-alist))
-
 (defmacro zenburn-with-color-variables (&rest body)
   "`let' bind all colors defined in `zenburn-colors-alist' around BODY.
 Also bind `class' to ((class color) (min-colors 89))."
@@ -95,7 +159,10 @@ Also bind `class' to ((class color) (min-colors 89))."
   `(let ((class '((class color) (min-colors 89)))
          ,@(mapcar (lambda (cons)
                      (list (intern (car cons)) (cdr cons)))
-                   zenburn-colors-alist))
+                   (append zenburn-default-colors-alist
+                           zenburn-override-colors-alist))
+         (z-variable-pitch (if zenburn-use-variable-pitch
+                               'variable-pitch 'default)))
      ,@body))
 
 ;;; Theme Faces
@@ -109,6 +176,7 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(link-visited ((t (:foreground ,zenburn-yellow-2 :underline t :weight normal))))
    `(default ((t (:foreground ,zenburn-fg :background ,zenburn-bg))))
    `(cursor ((t (:foreground ,zenburn-fg :background ,zenburn-fg+1))))
+   `(widget-field ((t (:foreground ,zenburn-fg :background ,zenburn-bg+3))))
    `(escape-glyph ((t (:foreground ,zenburn-yellow :weight bold))))
    `(fringe ((t (:foreground ,zenburn-fg :background ,zenburn-bg+1))))
    `(header-line ((t (:foreground ,zenburn-yellow
@@ -135,12 +203,23 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(compilation-mode-line-run ((t (:foreground ,zenburn-yellow :weight bold))))
 ;;;;; completions
    `(completions-annotations ((t (:foreground ,zenburn-fg-1))))
+;;;;; eww
+   '(eww-invalid-certificate ((t (:inherit error))))
+   '(eww-valid-certificate   ((t (:inherit success))))
 ;;;;; grep
    `(grep-context-face ((t (:foreground ,zenburn-fg))))
    `(grep-error-face ((t (:foreground ,zenburn-red-1 :weight bold :underline t))))
    `(grep-hit-face ((t (:foreground ,zenburn-blue))))
    `(grep-match-face ((t (:foreground ,zenburn-orange :weight bold))))
    `(match ((t (:background ,zenburn-bg-1 :foreground ,zenburn-orange :weight bold))))
+;;;;; hi-lock
+   `(hi-blue    ((t (:background ,zenburn-cyan    :foreground ,zenburn-bg-1))))
+   `(hi-green   ((t (:background ,zenburn-green+4 :foreground ,zenburn-bg-1))))
+   `(hi-pink    ((t (:background ,zenburn-magenta :foreground ,zenburn-bg-1))))
+   `(hi-yellow  ((t (:background ,zenburn-yellow  :foreground ,zenburn-bg-1))))
+   `(hi-blue-b  ((t (:foreground ,zenburn-blue    :weight     bold))))
+   `(hi-green-b ((t (:foreground ,zenburn-green+2 :weight     bold))))
+   `(hi-red-b   ((t (:foreground ,zenburn-red     :weight     bold))))
 ;;;;; info
    `(Info-quoted ((t (:inherit font-lock-constant-face))))
 ;;;;; isearch
@@ -157,7 +236,7 @@ Also bind `class' to ((class color) (min-colors 89))."
       (t :inverse-video t)))
    `(mode-line-buffer-id ((t (:foreground ,zenburn-yellow :weight bold))))
    `(mode-line-inactive
-     ((t (:foreground ,zenburn-green-1
+     ((t (:foreground ,zenburn-green-2
                       :background ,zenburn-bg-05
                       :box (:line-width -1 :style released-button)))))
    `(region ((,class (:background ,zenburn-bg-1))
@@ -168,7 +247,7 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; font lock
    `(font-lock-builtin-face ((t (:foreground ,zenburn-fg :weight bold))))
    `(font-lock-comment-face ((t (:foreground ,zenburn-green))))
-   `(font-lock-comment-delimiter-face ((t (:foreground ,zenburn-green-1))))
+   `(font-lock-comment-delimiter-face ((t (:foreground ,zenburn-green-2))))
    `(font-lock-constant-face ((t (:foreground ,zenburn-green+4))))
    `(font-lock-doc-face ((t (:foreground ,zenburn-green+2))))
    `(font-lock-function-name-face ((t (:foreground ,zenburn-cyan))))
@@ -183,6 +262,12 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(font-lock-warning-face ((t (:foreground ,zenburn-yellow-2 :weight bold))))
 
    `(c-annotation-face ((t (:inherit font-lock-constant-face))))
+;;;;; line numbers (Emacs 26.1 and above)
+   `(line-number ((t (:foreground ,zenburn-bg+3 :background ,zenburn-bg-05))))
+   `(line-number-current-line ((t (:inherit line-number :foreground ,zenburn-yellow-2))))
+;;;;; man
+   '(Man-overstrike ((t (:inherit font-lock-keyword-face))))
+   '(Man-underline  ((t (:inherit (font-lock-string-face underline)))))
 ;;;;; newsticker
    `(newsticker-date-face ((t (:foreground ,zenburn-fg))))
    `(newsticker-default-face ((t (:foreground ,zenburn-fg))))
@@ -201,6 +286,9 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(newsticker-treeview-obsolete-face ((t (:foreground ,zenburn-red))))
    `(newsticker-treeview-old-face ((t (:foreground ,zenburn-bg+3))))
    `(newsticker-treeview-selection-face ((t (:background ,zenburn-bg-1 :foreground ,zenburn-yellow))))
+;;;;; woman
+   '(woman-bold   ((t (:inherit font-lock-keyword-face))))
+   '(woman-italic ((t (:inherit (font-lock-string-face italic)))))
 ;;;; Third-party
 ;;;;; ace-jump
    `(ace-jump-face-background
@@ -232,6 +320,7 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(font-latex-italic-face ((t (:foreground ,zenburn-cyan :slant italic))))
    `(font-latex-string-face ((t (:inherit ,font-lock-string-face))))
    `(font-latex-math-face ((t (:foreground ,zenburn-orange))))
+   `(font-latex-script-char-face ((t (:foreground ,zenburn-orange))))
 ;;;;; agda-mode
    `(agda2-highlight-keyword-face ((t (:foreground ,zenburn-yellow :weight bold))))
    `(agda2-highlight-string-face ((t (:foreground ,zenburn-red))))
@@ -283,8 +372,8 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; bm
    `(bm-face ((t (:background ,zenburn-yellow-1 :foreground ,zenburn-bg))))
    `(bm-fringe-face ((t (:background ,zenburn-yellow-1 :foreground ,zenburn-bg))))
-   `(bm-fringe-persistent-face ((t (:background ,zenburn-green-1 :foreground ,zenburn-bg))))
-   `(bm-persistent-face ((t (:background ,zenburn-green-1 :foreground ,zenburn-bg))))
+   `(bm-fringe-persistent-face ((t (:background ,zenburn-green-2 :foreground ,zenburn-bg))))
+   `(bm-persistent-face ((t (:background ,zenburn-green-2 :foreground ,zenburn-bg))))
 ;;;;; calfw
    `(cfw:face-annotation ((t (:foreground ,zenburn-red :inherit cfw:face-day-title))))
    `(cfw:face-day-title ((t nil)))
@@ -313,7 +402,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(cider-traced-face ((t (:box (:color ,zenburn-cyan :line-width -1)))))
    `(cider-test-failure-face ((t (:background ,zenburn-red-4))))
    `(cider-test-error-face ((t (:background ,zenburn-magenta))))
-   `(cider-test-success-face ((t (:background ,zenburn-green-1))))
+   `(cider-test-success-face ((t (:background ,zenburn-green-2))))
+   `(cider-fringe-good-face ((t (:foreground ,zenburn-green+4))))
 ;;;;; circe
    `(circe-highlight-nick-face ((t (:foreground ,zenburn-cyan))))
    `(circe-my-message-face ((t (:foreground ,zenburn-fg))))
@@ -348,12 +438,12 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(debbugs-gnu-stale ((t (:foreground ,zenburn-orange))))
    `(debbugs-gnu-tagged ((t (:foreground ,zenburn-red))))
 ;;;;; diff
-   `(diff-added          ((t (:background "#335533" :foreground ,zenburn-green))))
+   `(diff-added          ((t (:background ,zenburn-green-5 :foreground ,zenburn-green+2))))
    `(diff-changed        ((t (:background "#555511" :foreground ,zenburn-yellow-1))))
-   `(diff-removed        ((t (:background "#553333" :foreground ,zenburn-red-2))))
-   `(diff-refine-added   ((t (:background "#338833" :foreground ,zenburn-green+4))))
-   `(diff-refine-change  ((t (:background "#888811" :foreground ,zenburn-yellow))))
-   `(diff-refine-removed ((t (:background "#883333" :foreground ,zenburn-red))))
+   `(diff-removed        ((t (:background ,zenburn-red-6 :foreground ,zenburn-red+1))))
+   `(diff-refine-added   ((t (:background ,zenburn-green-4 :foreground ,zenburn-green+3))))
+   `(diff-refine-changed ((t (:background "#888811" :foreground ,zenburn-yellow))))
+   `(diff-refine-removed ((t (:background ,zenburn-red-5 :foreground ,zenburn-red+2))))
    `(diff-header ((,class (:background ,zenburn-bg+2))
                   (t (:background ,zenburn-fg :foreground ,zenburn-bg))))
    `(diff-file-header
@@ -362,7 +452,7 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; diff-hl
    `(diff-hl-change ((,class (:foreground ,zenburn-blue :background ,zenburn-blue-2))))
    `(diff-hl-delete ((,class (:foreground ,zenburn-red+1 :background ,zenburn-red-1))))
-   `(diff-hl-insert ((,class (:foreground ,zenburn-green+1 :background ,zenburn-green-1))))
+   `(diff-hl-insert ((,class (:foreground ,zenburn-green+1 :background ,zenburn-green-2))))
 ;;;;; dim-autoload
    `(dim-autoload-cookie-line ((t :foreground ,zenburn-bg+1)))
 ;;;;; dired+
@@ -387,30 +477,52 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(diredp-number ((t (:foreground ,zenburn-green+1))))
    `(diredp-other-priv ((t (:foreground ,zenburn-yellow-1))))
    `(diredp-rare-priv ((t (:foreground ,zenburn-red-1))))
-   `(diredp-read-priv ((t (:foreground ,zenburn-green-1))))
+   `(diredp-read-priv ((t (:foreground ,zenburn-green-2))))
    `(diredp-symlink ((t (:foreground ,zenburn-yellow))))
    `(diredp-write-priv ((t (:foreground ,zenburn-magenta))))
 ;;;;; dired-async
    `(dired-async-failures ((t (:foreground ,zenburn-red :weight bold))))
    `(dired-async-message ((t (:foreground ,zenburn-yellow :weight bold))))
    `(dired-async-mode-message ((t (:foreground ,zenburn-yellow))))
+;;;;; diredfl
+   `(diredfl-compressed-file-suffix ((t (:foreground ,zenburn-orange))))
+   `(diredfl-date-time ((t (:foreground ,zenburn-magenta))))
+   `(diredfl-deletion ((t (:foreground ,zenburn-yellow))))
+   `(diredfl-deletion-file-name ((t (:foreground ,zenburn-red))))
+   `(diredfl-dir-heading ((t (:foreground ,zenburn-blue :background ,zenburn-bg-1))))
+   `(diredfl-dir-priv ((t (:foreground ,zenburn-cyan))))
+   `(diredfl-exec-priv ((t (:foreground ,zenburn-red))))
+   `(diredfl-executable-tag ((t (:foreground ,zenburn-green+1))))
+   `(diredfl-file-name ((t (:foreground ,zenburn-blue))))
+   `(diredfl-file-suffix ((t (:foreground ,zenburn-green))))
+   `(diredfl-flag-mark ((t (:foreground ,zenburn-yellow))))
+   `(diredfl-flag-mark-line ((t (:foreground ,zenburn-orange))))
+   `(diredfl-ignored-file-name ((t (:foreground ,zenburn-red))))
+   `(diredfl-link-priv ((t (:foreground ,zenburn-yellow))))
+   `(diredfl-no-priv ((t (:foreground ,zenburn-fg))))
+   `(diredfl-number ((t (:foreground ,zenburn-green+1))))
+   `(diredfl-other-priv ((t (:foreground ,zenburn-yellow-1))))
+   `(diredfl-rare-priv ((t (:foreground ,zenburn-red-1))))
+   `(diredfl-read-priv ((t (:foreground ,zenburn-green-1))))
+   `(diredfl-symlink ((t (:foreground ,zenburn-yellow))))
+   `(diredfl-write-priv ((t (:foreground ,zenburn-magenta))))
 ;;;;; ediff
-   `(ediff-current-diff-A ((t (:foreground ,zenburn-fg :background ,zenburn-red-4))))
-   `(ediff-current-diff-Ancestor ((t (:foreground ,zenburn-fg :background ,zenburn-red-4))))
-   `(ediff-current-diff-B ((t (:foreground ,zenburn-fg :background ,zenburn-green-1))))
-   `(ediff-current-diff-C ((t (:foreground ,zenburn-fg :background ,zenburn-blue-5))))
+   `(ediff-current-diff-A ((t (:inherit diff-removed))))
+   `(ediff-current-diff-Ancestor ((t (:inherit ediff-current-diff-A))))
+   `(ediff-current-diff-B ((t (:inherit diff-added))))
+   `(ediff-current-diff-C ((t (:foreground ,zenburn-blue+2 :background ,zenburn-blue-5))))
    `(ediff-even-diff-A ((t (:background ,zenburn-bg+1))))
    `(ediff-even-diff-Ancestor ((t (:background ,zenburn-bg+1))))
    `(ediff-even-diff-B ((t (:background ,zenburn-bg+1))))
    `(ediff-even-diff-C ((t (:background ,zenburn-bg+1))))
-   `(ediff-fine-diff-A ((t (:foreground ,zenburn-fg :background ,zenburn-red-2 :weight bold))))
-   `(ediff-fine-diff-Ancestor ((t (:foreground ,zenburn-fg :background ,zenburn-red-2 weight bold))))
-   `(ediff-fine-diff-B ((t (:foreground ,zenburn-fg :background ,zenburn-green :weight bold))))
-   `(ediff-fine-diff-C ((t (:foreground ,zenburn-fg :background ,zenburn-blue-3 :weight bold ))))
+   `(ediff-fine-diff-A ((t (:inherit diff-refine-removed :weight bold))))
+   `(ediff-fine-diff-Ancestor ((t (:inherit ediff-fine-diff-A))))
+   `(ediff-fine-diff-B ((t (:inherit diff-refine-added :weight bold))))
+   `(ediff-fine-diff-C ((t (:foreground ,zenburn-blue+3 :background ,zenburn-blue-4 :weight bold))))
    `(ediff-odd-diff-A ((t (:background ,zenburn-bg+2))))
-   `(ediff-odd-diff-Ancestor ((t (:background ,zenburn-bg+2))))
-   `(ediff-odd-diff-B ((t (:background ,zenburn-bg+2))))
-   `(ediff-odd-diff-C ((t (:background ,zenburn-bg+2))))
+   `(ediff-odd-diff-Ancestor ((t (:inherit ediff-odd-diff-A))))
+   `(ediff-odd-diff-B ((t (:inherit ediff-odd-diff-A))))
+   `(ediff-odd-diff-C ((t (:inherit ediff-odd-diff-A))))
 ;;;;; egg
    `(egg-text-base ((t (:foreground ,zenburn-fg))))
    `(egg-help-header-1 ((t (:foreground ,zenburn-yellow))))
@@ -515,7 +627,7 @@ Also bind `class' to ((class color) (min-colors 89))."
      ((((supports :underline (:style wave)))
        (:underline (:style wave :color ,zenburn-green)
                    :inherit unspecified :foreground unspecified :background unspecified))
-      (t (:foreground ,zenburn-green-1 :weight bold :underline t))))
+      (t (:foreground ,zenburn-green-2 :weight bold :underline t))))
 ;;;;; flyspell
    `(flyspell-duplicate
      ((((supports :underline (:style wave)))
@@ -530,9 +642,14 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(ack-file ((t (:foreground ,zenburn-blue))))
    `(ack-line ((t (:foreground ,zenburn-yellow))))
    `(ack-match ((t (:foreground ,zenburn-orange :background ,zenburn-bg-1 :weight bold))))
+;;;;; git-annex
+   '(git-annex-dired-annexed-available ((t (:inherit success :weight normal))))
+   '(git-annex-dired-annexed-unavailable ((t (:inherit error :weight normal))))
 ;;;;; git-commit
    `(git-commit-comment-action  ((,class (:foreground ,zenburn-green+1 :weight bold))))
-   `(git-commit-comment-branch  ((,class (:foreground ,zenburn-blue+1  :weight bold))))
+   `(git-commit-comment-branch  ((,class (:foreground ,zenburn-blue+1  :weight bold)))) ; obsolete
+   `(git-commit-comment-branch-local  ((,class (:foreground ,zenburn-blue+1  :weight bold))))
+   `(git-commit-comment-branch-remote ((,class (:foreground ,zenburn-green  :weight bold))))
    `(git-commit-comment-heading ((,class (:foreground ,zenburn-yellow  :weight bold))))
 ;;;;; git-gutter
    `(git-gutter:added ((t (:foreground ,zenburn-green :weight bold :inverse-video t))))
@@ -611,10 +728,16 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(gnus-group-news-low-empty ((t (:foreground ,zenburn-bg+2))))
    `(gnus-signature ((t (:foreground ,zenburn-yellow))))
    `(gnus-x ((t (:background ,zenburn-fg :foreground ,zenburn-bg))))
+   `(mm-uu-extract ((t (:background ,zenburn-bg-05 :foreground ,zenburn-green+1))))
+;;;;; go-guru
+   `(go-guru-hl-identifier-face ((t (:foreground ,zenburn-bg-1 :background ,zenburn-green+1))))
 ;;;;; guide-key
    `(guide-key/highlight-command-face ((t (:foreground ,zenburn-blue))))
    `(guide-key/key-face ((t (:foreground ,zenburn-green))))
    `(guide-key/prefix-command-face ((t (:foreground ,zenburn-green+1))))
+;;;;; hackernews
+   '(hackernews-comment-count ((t (:inherit link-visited :underline nil))))
+   '(hackernews-link          ((t (:inherit link         :underline nil))))
 ;;;;; helm
    `(helm-header
      ((t (:foreground ,zenburn-green
@@ -707,14 +830,15 @@ Also bind `class' to ((class color) (min-colors 89))."
                                       :underline t :weight bold))))
 ;;;;; ivy
    `(ivy-confirm-face ((t (:foreground ,zenburn-green :background ,zenburn-bg))))
-   `(ivy-match-required-face ((t (:foreground ,zenburn-red :background ,zenburn-bg))))
-   `(ivy-remote ((t (:foreground ,zenburn-blue :background ,zenburn-bg))))
-   `(ivy-subdir ((t (:foreground ,zenburn-yellow :background ,zenburn-bg))))
    `(ivy-current-match ((t (:foreground ,zenburn-yellow :weight bold :underline t))))
+   `(ivy-cursor ((t (:foreground ,zenburn-bg :background ,zenburn-fg))))
+   `(ivy-match-required-face ((t (:foreground ,zenburn-red :background ,zenburn-bg))))
    `(ivy-minibuffer-match-face-1 ((t (:background ,zenburn-bg+1))))
-   `(ivy-minibuffer-match-face-2 ((t (:background ,zenburn-green-1))))
+   `(ivy-minibuffer-match-face-2 ((t (:background ,zenburn-green-2))))
    `(ivy-minibuffer-match-face-3 ((t (:background ,zenburn-green))))
    `(ivy-minibuffer-match-face-4 ((t (:background ,zenburn-green+1))))
+   `(ivy-remote ((t (:foreground ,zenburn-blue :background ,zenburn-bg))))
+   `(ivy-subdir ((t (:foreground ,zenburn-yellow :background ,zenburn-bg))))
 ;;;;; ido-mode
    `(ido-first-match ((t (:foreground ,zenburn-yellow :weight bold))))
    `(ido-only-match ((t (:foreground ,zenburn-orange :weight bold))))
@@ -741,13 +865,13 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; js2-mode
    `(js2-warning ((t (:underline ,zenburn-orange))))
    `(js2-error ((t (:foreground ,zenburn-red :weight bold))))
-   `(js2-jsdoc-tag ((t (:foreground ,zenburn-green-1))))
+   `(js2-jsdoc-tag ((t (:foreground ,zenburn-green-2))))
    `(js2-jsdoc-type ((t (:foreground ,zenburn-green+2))))
    `(js2-jsdoc-value ((t (:foreground ,zenburn-green+3))))
    `(js2-function-param ((t (:foreground, zenburn-orange))))
    `(js2-external-variable ((t (:foreground ,zenburn-orange))))
 ;;;;; additional js2 mode attributes for better syntax highlighting
-   `(js2-instance-member ((t (:foreground ,zenburn-green-1))))
+   `(js2-instance-member ((t (:foreground ,zenburn-green-2))))
    `(js2-jsdoc-html-tag-delimiter ((t (:foreground ,zenburn-orange))))
    `(js2-jsdoc-html-tag-name ((t (:foreground ,zenburn-red-1))))
    `(js2-object-property ((t (:foreground ,zenburn-blue+1))))
@@ -816,6 +940,12 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(magit-section-highlight           ((t (:background ,zenburn-bg+05))))
    `(magit-section-heading             ((t (:foreground ,zenburn-yellow :weight bold))))
    `(magit-section-heading-selection   ((t (:foreground ,zenburn-orange :weight bold))))
+
+   `(magit-diff-added ((t (:inherit diff-added))))
+   `(magit-diff-added-highlight ((t (:inherit diff-refine-added))))
+   `(magit-diff-removed ((t (:inherit diff-removed))))
+   `(magit-diff-removed-highlight ((t (:inherit diff-refine-removed))))
+
    `(magit-diff-file-heading           ((t (:weight bold))))
    `(magit-diff-file-heading-highlight ((t (:background ,zenburn-bg+05  :weight bold))))
    `(magit-diff-file-heading-selection ((t (:background ,zenburn-bg+05
@@ -832,7 +962,7 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(magit-diffstat-removed ((t (:foreground ,zenburn-red))))
 ;;;;;; popup
    `(magit-popup-heading             ((t (:foreground ,zenburn-yellow  :weight bold))))
-   `(magit-popup-key                 ((t (:foreground ,zenburn-green-1 :weight bold))))
+   `(magit-popup-key                 ((t (:foreground ,zenburn-green-2 :weight bold))))
    `(magit-popup-argument            ((t (:foreground ,zenburn-green   :weight bold))))
    `(magit-popup-disabled-argument   ((t (:foreground ,zenburn-fg-1    :weight normal))))
    `(magit-popup-option-value        ((t (:foreground ,zenburn-blue-2  :weight bold))))
@@ -876,6 +1006,9 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(magit-signature-good      ((t (:foreground ,zenburn-green))))
    `(magit-signature-bad       ((t (:foreground ,zenburn-red))))
    `(magit-signature-untrusted ((t (:foreground ,zenburn-yellow))))
+   `(magit-signature-expired   ((t (:foreground ,zenburn-orange))))
+   `(magit-signature-revoked   ((t (:foreground ,zenburn-magenta))))
+   '(magit-signature-error     ((t (:inherit    magit-signature-bad))))
    `(magit-cherry-unmatched    ((t (:foreground ,zenburn-cyan))))
    `(magit-cherry-equivalent   ((t (:foreground ,zenburn-magenta))))
    `(magit-reflog-commit       ((t (:foreground ,zenburn-green))))
@@ -887,6 +1020,24 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(magit-reflog-cherry-pick  ((t (:foreground ,zenburn-green))))
    `(magit-reflog-remote       ((t (:foreground ,zenburn-cyan))))
    `(magit-reflog-other        ((t (:foreground ,zenburn-cyan))))
+;;;;; markup-faces
+   `(markup-anchor-face ((t (:foreground ,zenburn-blue+1))))
+   `(markup-code-face ((t (:inherit font-lock-constant-face))))
+   `(markup-command-face ((t (:foreground ,zenburn-yellow))))
+   `(markup-emphasis-face ((t (:inherit bold))))
+   `(markup-internal-reference-face ((t (:foreground ,zenburn-yellow-2 :underline t))))
+   `(markup-list-face ((t (:foreground ,zenburn-fg+1))))
+   `(markup-meta-face ((t (:foreground ,zenburn-yellow))))
+   `(markup-meta-hide-face ((t (:foreground ,zenburn-yellow))))
+   `(markup-secondary-text-face ((t (:foreground ,zenburn-yellow-1))))
+   `(markup-title-0-face ((t (:inherit font-lock-function-name-face :weight bold))))
+   `(markup-title-1-face ((t (:inherit font-lock-function-name-face :weight bold))))
+   `(markup-title-2-face ((t (:inherit font-lock-function-name-face :weight bold))))
+   `(markup-title-3-face ((t (:inherit font-lock-function-name-face :weight bold))))
+   `(markup-title-4-face ((t (:inherit font-lock-function-name-face :weight bold))))
+   `(markup-typewriter-face ((t (:inherit font-lock-constant-face))))
+   `(markup-verbatim-face ((t (:inherit font-lock-constant-face))))
+   `(markup-value-face ((t (:foreground ,zenburn-yellow))))
 ;;;;; message-mode
    `(message-cited-text ((t (:inherit font-lock-comment-face))))
    `(message-header-name ((t (:foreground ,zenburn-green+1))))
@@ -947,13 +1098,25 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(nav-face-hdir ((t (:foreground ,zenburn-red))))
    `(nav-face-file ((t (:foreground ,zenburn-fg))))
    `(nav-face-hfile ((t (:foreground ,zenburn-red-4))))
+;;;;; merlin
+   `(merlin-type-face ((t (:inherit highlight))))
+   `(merlin-compilation-warning-face
+     ((((supports :underline (:style wave)))
+       (:underline (:style wave :color ,zenburn-orange)))
+      (t
+       (:underline ,zenburn-orange))))
+   `(merlin-compilation-error-face
+     ((((supports :underline (:style wave)))
+       (:underline (:style wave :color ,zenburn-red)))
+      (t
+       (:underline ,zenburn-red))))
 ;;;;; mu4e
    `(mu4e-cited-1-face ((t (:foreground ,zenburn-blue    :slant italic))))
    `(mu4e-cited-2-face ((t (:foreground ,zenburn-green+2 :slant italic))))
    `(mu4e-cited-3-face ((t (:foreground ,zenburn-blue-2  :slant italic))))
    `(mu4e-cited-4-face ((t (:foreground ,zenburn-green   :slant italic))))
    `(mu4e-cited-5-face ((t (:foreground ,zenburn-blue-4  :slant italic))))
-   `(mu4e-cited-6-face ((t (:foreground ,zenburn-green-1 :slant italic))))
+   `(mu4e-cited-6-face ((t (:foreground ,zenburn-green-2 :slant italic))))
    `(mu4e-cited-7-face ((t (:foreground ,zenburn-blue    :slant italic))))
    `(mu4e-replied-face ((t (:foreground ,zenburn-bg+3))))
    `(mu4e-trashed-face ((t (:foreground ,zenburn-bg+3 :strike-through t))))
@@ -993,15 +1156,23 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(org-done ((t (:weight bold :weight bold :foreground ,zenburn-green+3))))
    `(org-formula ((t (:foreground ,zenburn-yellow-2))))
    `(org-headline-done ((t (:foreground ,zenburn-green+3))))
-   `(org-hide ((t (:foreground ,zenburn-bg-1))))
-   `(org-level-1 ((t (:foreground ,zenburn-orange))))
-   `(org-level-2 ((t (:foreground ,zenburn-green+4))))
-   `(org-level-3 ((t (:foreground ,zenburn-blue-1))))
-   `(org-level-4 ((t (:foreground ,zenburn-yellow-2))))
-   `(org-level-5 ((t (:foreground ,zenburn-cyan))))
-   `(org-level-6 ((t (:foreground ,zenburn-green+2))))
-   `(org-level-7 ((t (:foreground ,zenburn-red-4))))
-   `(org-level-8 ((t (:foreground ,zenburn-blue-4))))
+   `(org-hide ((t (:foreground ,zenburn-bg))))
+   `(org-level-1 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-orange
+                               ,@(when zenburn-scale-org-headlines
+                                   (list :height zenburn-height-plus-4))))))
+   `(org-level-2 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-green+4
+                               ,@(when zenburn-scale-org-headlines
+                                   (list :height zenburn-height-plus-3))))))
+   `(org-level-3 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-blue-1
+                               ,@(when zenburn-scale-org-headlines
+                                   (list :height zenburn-height-plus-2))))))
+   `(org-level-4 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-yellow-2
+                               ,@(when zenburn-scale-org-headlines
+                                   (list :height zenburn-height-plus-1))))))
+   `(org-level-5 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-cyan))))
+   `(org-level-6 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-green+2))))
+   `(org-level-7 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-red-4))))
+   `(org-level-8 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-blue-4))))
    `(org-link ((t (:foreground ,zenburn-yellow-2 :underline t))))
    `(org-scheduled ((t (:foreground ,zenburn-green+4))))
    `(org-scheduled-previously ((t (:foreground ,zenburn-red))))
@@ -1020,25 +1191,40 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(org-mode-line-clock-overrun ((t (:foreground ,zenburn-bg :background ,zenburn-red-1))))
    `(org-ellipsis ((t (:foreground ,zenburn-yellow-1 :underline t))))
    `(org-footnote ((t (:foreground ,zenburn-cyan :underline t))))
-   `(org-document-title ((t (:foreground ,zenburn-blue))))
+   `(org-document-title ((t (:inherit ,z-variable-pitch :foreground ,zenburn-blue
+                                         :weight bold :height ,zenburn-height-plus-4))))
    `(org-document-info ((t (:foreground ,zenburn-blue))))
    `(org-habit-ready-face ((t :background ,zenburn-green)))
    `(org-habit-alert-face ((t :background ,zenburn-yellow-1 :foreground ,zenburn-bg)))
    `(org-habit-clear-face ((t :background ,zenburn-blue-3)))
    `(org-habit-overdue-face ((t :background ,zenburn-red-3)))
    `(org-habit-clear-future-face ((t :background ,zenburn-blue-4)))
-   `(org-habit-ready-future-face ((t :background ,zenburn-green-1)))
+   `(org-habit-ready-future-face ((t :background ,zenburn-green-2)))
    `(org-habit-alert-future-face ((t :background ,zenburn-yellow-2 :foreground ,zenburn-bg)))
    `(org-habit-overdue-future-face ((t :background ,zenburn-red-4)))
+;;;;; org-ref
+   `(org-ref-ref-face ((t :underline t)))
+   `(org-ref-label-face ((t :underline t)))
+   `(org-ref-cite-face ((t :underline t)))
+   `(org-ref-glossary-face ((t :underline t)))
+   `(org-ref-acronym-face ((t :underline t)))
 ;;;;; outline
-   `(outline-1 ((t (:foreground ,zenburn-orange))))
-   `(outline-2 ((t (:foreground ,zenburn-green+4))))
-   `(outline-3 ((t (:foreground ,zenburn-blue-1))))
-   `(outline-4 ((t (:foreground ,zenburn-yellow-2))))
-   `(outline-5 ((t (:foreground ,zenburn-cyan))))
-   `(outline-6 ((t (:foreground ,zenburn-green+2))))
-   `(outline-7 ((t (:foreground ,zenburn-red-4))))
-   `(outline-8 ((t (:foreground ,zenburn-blue-4))))
+   `(outline-1 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-orange
+                             ,@(when zenburn-scale-outline-headlines
+                                 (list :height zenburn-height-plus-4))))))
+   `(outline-2 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-green+4
+                             ,@(when zenburn-scale-outline-headlines
+                                 (list :height zenburn-height-plus-3))))))
+   `(outline-3 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-blue-1
+                             ,@(when zenburn-scale-outline-headlines
+                                 (list :height zenburn-height-plus-2))))))
+   `(outline-4 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-yellow-2
+                             ,@(when zenburn-scale-outline-headlines
+                                 (list :height zenburn-height-plus-1))))))
+   `(outline-5 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-cyan))))
+   `(outline-6 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-green+2))))
+   `(outline-7 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-red-4))))
+   `(outline-8 ((t (:inherit ,z-variable-pitch :foreground ,zenburn-blue-4))))
 ;;;;; p4
    `(p4-depot-added-face ((t :inherit diff-added)))
    `(p4-depot-branch-op-face ((t :inherit diff-changed)))
@@ -1049,6 +1235,12 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(p4-diff-file-face ((t :inherit diff-file-header)))
    `(p4-diff-head-face ((t :inherit diff-header)))
    `(p4-diff-ins-face ((t :inherit diff-added)))
+;;;;; c/perl
+   `(cperl-nonoverridable-face ((t (:foreground ,zenburn-magenta))))
+   `(cperl-array-face ((t (:foreground ,zenburn-yellow, :backgorund ,zenburn-bg))))
+   `(cperl-hash-face ((t (:foreground ,zenburn-yellow-1, :background ,zenburn-bg))))
+;;;;; paren-face
+   `(parenthesis ((t (:foreground ,zenburn-fg-1))))
 ;;;;; perspective
    `(persp-selected-face ((t (:foreground ,zenburn-yellow-2 :inherit mode-line))))
 ;;;;; powerline
@@ -1110,6 +1302,16 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(reb-match-1 ((t (:foreground ,zenburn-bg :background ,zenburn-blue))))
    `(reb-match-2 ((t (:foreground ,zenburn-bg :background ,zenburn-orange))))
    `(reb-match-3 ((t (:foreground ,zenburn-bg :background ,zenburn-red))))
+;;;;; realgud
+   `(realgud-overlay-arrow1 ((t (:foreground ,zenburn-green))))
+   `(realgud-overlay-arrow2 ((t (:foreground ,zenburn-yellow))))
+   `(realgud-overlay-arrow3 ((t (:foreground ,zenburn-orange))))
+   `(realgud-bp-enabled-face ((t (:inherit error))))
+   `(realgud-bp-disabled-face ((t (:inherit secondary-selection))))
+   `(realgud-bp-line-enabled-face ((t (:box (:color ,zenburn-red :style nil)))))
+   `(realgud-bp-line-disabled-face ((t (:box (:color "grey70" :style nil)))))
+   `(realgud-line-number ((t (:foreground ,zenburn-yellow))))
+   `(realgud-backtrace-number ((t (:foreground ,zenburn-yellow, :weight bold))))
 ;;;;; regex-tool
    `(regex-tool-matched-face ((t (:background ,zenburn-blue-4 :weight bold))))
 ;;;;; rpm-mode
@@ -1128,13 +1330,13 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(rst-level-3-face ((t (:foreground ,zenburn-blue-1))))
    `(rst-level-4-face ((t (:foreground ,zenburn-yellow-2))))
    `(rst-level-5-face ((t (:foreground ,zenburn-cyan))))
-   `(rst-level-6-face ((t (:foreground ,zenburn-green-1))))
+   `(rst-level-6-face ((t (:foreground ,zenburn-green-2))))
 ;;;;; sh-mode
    `(sh-heredoc     ((t (:foreground ,zenburn-yellow :weight bold))))
    `(sh-quoted-exec ((t (:foreground ,zenburn-red))))
 ;;;;; show-paren
    `(show-paren-mismatch ((t (:foreground ,zenburn-red+1 :background ,zenburn-bg+3 :weight bold))))
-   `(show-paren-match ((t (:background ,zenburn-bg+3 :weight bold))))
+   `(show-paren-match ((t (:foreground ,zenburn-fg :background ,zenburn-bg+3 :weight bold))))
 ;;;;; smart-mode-line
    ;; use (setq sml/theme nil) to enable Zenburn for sml
    `(sml/global ((,class (:foreground ,zenburn-fg :weight bold))))
@@ -1191,6 +1393,20 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(speedbar-selected-face ((t (:foreground ,zenburn-red))))
    `(speedbar-separator-face ((t (:foreground ,zenburn-bg :background ,zenburn-blue-1))))
    `(speedbar-tag-face ((t (:foreground ,zenburn-yellow))))
+;;;;; sx
+   `(sx-custom-button
+     ((t (:background ,zenburn-fg :foreground ,zenburn-bg-1
+          :box (:line-width 3 :style released-button) :height 0.9))))
+   `(sx-question-list-answers
+     ((t (:foreground ,zenburn-green+3
+          :height 1.0 :inherit sx-question-list-parent))))
+   `(sx-question-mode-accepted
+     ((t (:foreground ,zenburn-green+3
+          :height 1.3 :inherit sx-question-mode-title))))
+   '(sx-question-mode-content-face ((t (:inherit highlight))))
+   `(sx-question-mode-kbd-tag
+     ((t (:box (:color ,zenburn-bg-1 :line-width 3 :style released-button)
+          :height 0.9 :weight semi-bold))))
 ;;;;; tabbar
    `(tabbar-button ((t (:foreground ,zenburn-fg
                                     :background ,zenburn-bg))))
@@ -1319,12 +1535,15 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; ansi-color
    `(ansi-color-names-vector [,zenburn-bg ,zenburn-red ,zenburn-green ,zenburn-yellow
                                           ,zenburn-blue ,zenburn-magenta ,zenburn-cyan ,zenburn-fg])
+;;;;; company-quickhelp
+   `(company-quickhelp-color-background ,zenburn-bg+1)
+   `(company-quickhelp-color-foreground ,zenburn-fg)
 ;;;;; fill-column-indicator
    `(fci-rule-color ,zenburn-bg-05)
 ;;;;; nrepl-client
    `(nrepl-message-colors
      '(,zenburn-red ,zenburn-orange ,zenburn-yellow ,zenburn-green ,zenburn-green+4
-                    ,zenburn-cyan ,zenburn-blue+1 ,zenburn-magenta))
+       ,zenburn-cyan ,zenburn-blue+1 ,zenburn-magenta))
 ;;;;; pdf-tools
    `(pdf-view-midnight-colors '(,zenburn-fg . ,zenburn-bg-05))
 ;;;;; vc-annotate
@@ -1335,7 +1554,7 @@ Also bind `class' to ((class color) (min-colors 89))."
        ( 80. . ,zenburn-yellow-2)
        (100. . ,zenburn-yellow-1)
        (120. . ,zenburn-yellow)
-       (140. . ,zenburn-green-1)
+       (140. . ,zenburn-green-2)
        (160. . ,zenburn-green)
        (180. . ,zenburn-green+1)
        (200. . ,zenburn-green+2)
